@@ -8,7 +8,6 @@ from datetime import datetime
 from xml.dom import minidom
 from xml.etree import ElementTree
 from xml.etree.ElementTree import Element, SubElement
-from xml.etree.ElementTree import ElementTree
 
 import boto3
 from boto3.s3.transfer import TransferConfig
@@ -137,7 +136,7 @@ def __make_representation_multiple_co__(xip, rep_name, rep_type, rep_files, io_r
     return refs_dict
 
 
-def cvs_to_cmis_xslt(csv_file, xml_namespace, root_element, title="Metadata Title"):
+def cvs_to_cmis_xslt(csv_file, xml_namespace, root_element, title="Metadata Title", export_folder=None):
     """
             Create a custom CMIS transform to display metadata within UA.
 
@@ -163,7 +162,7 @@ def cvs_to_cmis_xslt(csv_file, xml_namespace, root_element, title="Metadata Titl
                                                     "xmlns": "http://www.tessella.com/sdb/cmis/metadata",
                                                     "exclude-result-prefixes": "csv"})
 
-    xml_output = xml.etree.ElementTree.SubElement(xml_stylesheet, "xsl:output", {"method": "xml", "indent": "yes"})
+    xml.etree.ElementTree.SubElement(xml_stylesheet, "xsl:output", {"method": "xml", "indent": "yes"})
 
     xml_template = xml.etree.ElementTree.SubElement(xml_stylesheet, "xsl:template", {"match": "csv:" + root_element})
 
@@ -192,12 +191,16 @@ def cvs_to_cmis_xslt(csv_file, xml_namespace, root_element, title="Metadata Titl
         "select": "fn:replace(translate(local-name(), '_', ' '), '([a-z])([A-Z])', '$1 $2')"})
 
     xml_request = xml.etree.ElementTree.tostring(xml_stylesheet, encoding='utf-8', xml_declaration=True)
-    file = open(root_element + "-cmis.xslt", "wt", encoding="utf-8")
+    cmis_xslt = root_element + "-cmis.xslt"
+    if export_folder is not None:
+        cmis_xslt = os.path.join(export_folder, cmis_xslt)
+    file = open(cmis_xslt, "wt", encoding="utf-8")
     file.write(xml_request.decode("utf-8"))
     file.close()
+    return cmis_xslt
 
 
-def cvs_to_xsd(csv_file, xml_namespace, root_element):
+def cvs_to_xsd(csv_file, xml_namespace, root_element, export_folder=None):
     """
         Create a XSD definition based on the csv file
 
@@ -223,12 +226,17 @@ def cvs_to_xsd(csv_file, xml_namespace, root_element):
     for header in headers:
         xml_e = xml.etree.ElementTree.SubElement(xml_sequence, "xs:element", {"type": "xs:string", "name": header})
     xml_request = xml.etree.ElementTree.tostring(xml_schema, encoding='utf-8', xml_declaration=True)
-    file = open(root_element + ".xsd", "wt", encoding="utf-8")
+
+    xsd_file = root_element + ".xsd"
+    if export_folder is not None:
+        xsd_file = os.path.join(export_folder, xsd_file)
+    file = open(xsd_file, "wt", encoding="utf-8")
     file.write(xml_request.decode("utf-8"))
     file.close()
+    return xsd_file
 
 
-def csv_to_search_xml(csv_file, xml_namespace, root_element, title="Metadata Title"):
+def csv_to_search_xml(csv_file, xml_namespace, root_element, title="Metadata Title", export_folder=None):
     """
         Create a custom Preservica search index based on the columns in a csv file
 
@@ -263,13 +271,16 @@ def csv_to_search_xml(csv_file, xml_namespace, root_element, title="Metadata Tit
         xml_term = xml.etree.ElementTree.SubElement(xml_index, "term", attr)
 
     xml_request = xml.etree.ElementTree.tostring(xml_index, encoding='utf-8', xml_declaration=True)
-    name = root_element + "-index.xml"
-    file = open(name, "wt", encoding="utf-8")
+    search_xml = root_element + "-index.xml"
+    if export_folder is not None:
+        search_xml = os.path.join(export_folder, search_xml)
+    file = open(search_xml, "wt", encoding="utf-8")
     file.write(xml_request.decode("utf-8"))
     file.close()
+    return search_xml
 
 
-def cvs_to_xml(csv_file, xml_namespace, root_element, file_name_column="filename"):
+def cvs_to_xml(csv_file, xml_namespace, root_element, file_name_column="filename", export_folder=None):
     """
     Export the rows of a CSV file as XML metadata documents which can be added to Preservica assets
 
@@ -301,9 +312,12 @@ def cvs_to_xml(csv_file, xml_namespace, root_element, file_name_column="filename
                         file_name = value
                 xml_request = xml.etree.ElementTree.tostring(xml_object, encoding='utf-8', xml_declaration=True)
                 name = file_name + ".xml"
+                if export_folder is not None:
+                    name = os.path.join(export_folder, name)
                 file = open(name, "wt", encoding="utf-8")
                 file.write(xml_request.decode("utf-8"))
                 file.close()
+                yield name
 
 
 def complex_asset_package(preservation_files_list=None, access_files_list=None, export_folder=None,
